@@ -1,4 +1,6 @@
 from .drafter import Drafter
 from .message import create_email_message
 from .sender import Sender
-from .utils import assert_unique, log, localhost_send
+from .utils import assert_unique
+from .utils import localhost_send
+from .utils import log
